==> emid-0.0.0.tar.gz: emid-0.0.0/prep-release/emid_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name></name>
    <message>
        <location filename="../emid/global_parameters.py" line="149"/>
        <source>custom</source>
        <translation>personnalisé</translation>
    </message>
</context>
<context>
    <name>Preferences Window</name>
    <message>
        <location filename="../emid/global_parameters.py" line="82"/>
        <source>System Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="83"/>
        <source>en</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="84"/>
        <source>it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="85"/>
        <source>fr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="86"/>
        <source>es</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="87"/>
        <source>el</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="90"/>
        <source>US</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="91"/>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="93"/>
        <source>IT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="94"/>
        <source>CH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="95"/>
        <source>FR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="96"/>
        <source>CA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="98"/>
        <source>ES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="99"/>
        <source>BO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="100"/>
        <source>CL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="102"/>
        <source>GR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="103"/>
        <source>CY</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainWin</name>
    <message>
        <location filename="../identipy.pyw" line="65"/>
        <source>Identipy</source>
        <translation type="obsolete">Indentipy</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="81"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="83"/>
        <source>Phones</source>
        <translation>Casque</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="87"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="99"/>
        <source>Setup Listener</source>
        <translation>Configuration participant</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="173"/>
        <source>Start</source>
        <translation>Commencer</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Happy</source>
        <translation>Heureuse</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Sad</source>
        <translation>Triste</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Neutral</source>
        <translation>Neutre</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Angry</source>
        <translation>En colère</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Scared</source>
        <translation>Effrayée</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="303"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="193"/>
        <source>Finished</source>
        <translation>Fini</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="303"/>
        <source>Running</source>
        <translation>En cours d'execution</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="247"/>
        <source>Listener ID: </source>
        <translation>ID Participant :</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="252"/>
        <source>Choose trial list file</source>
        <translation>Sélectionner le fichier avec la liste des essays</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="273"/>
        <source>CSV (*.csv *CSV *Csv);;All Files (*)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="273"/>
        <source>Choose file to write results</source>
        <translation>Sélectionner le fichier des résultats</translation>
    </message>
    <message>
        <location filename="identipy.py" line="273"/>
        <source>All Files (*)</source>
        <translation type="obsolete">Tous les fichiers</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="65"/>
        <source>Emid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>phonesDialog</name>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="62"/>
        <source>Phones</source>
        <translation>Casque</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="62"/>
        <source>Max Level</source>
        <translation>Niveau Maximal</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="67"/>
        <source>Rename Phones</source>
        <translation>Rénommer Casque</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="70"/>
        <source>Change Max Level</source>
        <translation>Changer le niveau maximal</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="74"/>
        <source>Add Phones</source>
        <translation>Ajouter des écouters</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="77"/>
        <source>Remove Phones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="105"/>
        <source>Calibration Tone:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="108"/>
        <source>Frequency (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="114"/>
        <source>Level (dB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="120"/>
        <source>Duration (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="126"/>
        <source>Ramps (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="132"/>
        <source>Ear:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="138"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="143"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="165"/>
        <source>Edit Phones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="264"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="261"/>
        <source>Only one label can be renamed at a time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="182"/>
        <source>New name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="196"/>
        <source>Input Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="190"/>
        <source>Only one item can be edited at a time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="195"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="247"/>
        <source>Only one phone left. Cannot remove!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="264"/>
        <source>Please, select a phone in the table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="70"/>
        <source>Language (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="78"/>
        <source>Country (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="85"/>
        <source>Start delay (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="91"/>
        <source>CSV separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="117"/>
        <source>Phones:</source>
        <translation>Casques :</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="126"/>
        <source>Play Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="131"/>
        <source>Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="336"/>
        <source>custom</source>
        <translation>personnalisé</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="160"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="177"/>
        <source>Buffer Size (samples):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="194"/>
        <source>WAV Manager (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="211"/>
        <source>Append silence to each sound (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="222"/>
        <source>Genera&amp;l</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="223"/>
        <source>Soun&amp;d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="355"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="355"/>
        <source>There are unsaved changes. Apply Changes?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>responseLight</name>
    <message>
        <location filename="../emid/__main__.py" line="448"/>
        <source>Light &amp; Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="424"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="460"/>
        <source>Light &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="482"/>
        <source>Light &amp; Text &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="430"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="467"/>
        <source>Text &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="441"/>
        <source>Smiley</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> emid-0.0.4.tar.gz: emid-0.0.4/prep-release/emid_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name></name>
    <message>
        <location filename="../emid/global_parameters.py" line="155"/>
        <source>custom</source>
        <translation type="unfinished">personnalisé</translation>
    </message>
</context>
<context>
    <name>Preferences Window</name>
    <message>
        <location filename="../emid/global_parameters.py" line="88"/>
        <source>System Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="89"/>
        <source>en</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="90"/>
        <source>it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="91"/>
        <source>fr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="92"/>
        <source>es</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="93"/>
        <source>el</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="96"/>
        <source>US</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="97"/>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="99"/>
        <source>IT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="100"/>
        <source>CH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="101"/>
        <source>FR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="102"/>
        <source>CA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="104"/>
        <source>ES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="105"/>
        <source>BO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="106"/>
        <source>CL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="108"/>
        <source>GR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/global_parameters.py" line="109"/>
        <source>CY</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainWin</name>
    <message>
        <location filename="../emid/__main__.py" line="65"/>
        <source>emid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="81"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="83"/>
        <source>Phones</source>
        <translation>Casque</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="87"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="99"/>
        <source>Setup Listener</source>
        <translation>Configuration participant</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="173"/>
        <source>Start</source>
        <translation>Commencer</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Happy</source>
        <translation>Heureuse</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Sad</source>
        <translation>Triste</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Neutral</source>
        <translation>Neutre</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Angry</source>
        <translation>En colère</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="130"/>
        <source>Scared</source>
        <translation>Effrayée</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="303"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="193"/>
        <source>Finished</source>
        <translation>Fini</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="303"/>
        <source>Running</source>
        <translation>En cours d'execution</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="247"/>
        <source>Listener ID: </source>
        <translation>ID Participant :</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="252"/>
        <source>Choose trial list file</source>
        <translation>Sélectionner le fichier avec la liste des essays</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="273"/>
        <source>CSV (*.csv *CSV *Csv);;All Files (*)</source>
        <translation type="unfinished">Tous les fichiers</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="273"/>
        <source>Choose file to write results</source>
        <translation>Sélectionner le fichier des résultats</translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="273"/>
        <source>Identipy</source>
        <translation type="obsolete">Indentipy</translation>
    </message>
</context>
<context>
    <name>phonesDialog</name>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="62"/>
        <source>Phones</source>
        <translation>Casque</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="62"/>
        <source>Max Level</source>
        <translation>Niveau Maximal</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="67"/>
        <source>Rename Phones</source>
        <translation>Rénommer Casque</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="70"/>
        <source>Change Max Level</source>
        <translation>Changer le niveau maximal</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="74"/>
        <source>Add Phones</source>
        <translation>Ajouter des écouters</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="77"/>
        <source>Remove Phones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="105"/>
        <source>Calibration Tone:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="108"/>
        <source>Frequency (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="114"/>
        <source>Level (dB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="120"/>
        <source>Duration (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="126"/>
        <source>Ramps (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="132"/>
        <source>Ear:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="134"/>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="138"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="143"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="165"/>
        <source>Edit Phones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="264"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="261"/>
        <source>Only one label can be renamed at a time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="182"/>
        <source>New name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="196"/>
        <source>Input Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="190"/>
        <source>Only one item can be edited at a time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="195"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="247"/>
        <source>Only one phone left. Cannot remove!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_phones.py" line="264"/>
        <source>Please, select a phone in the table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="70"/>
        <source>Language (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="78"/>
        <source>Country (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="85"/>
        <source>Start delay (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="91"/>
        <source>CSV separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="117"/>
        <source>Phones:</source>
        <translation>Casques :</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="126"/>
        <source>Play Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="131"/>
        <source>Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="336"/>
        <source>custom</source>
        <translation>personnalisé</translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="160"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="177"/>
        <source>Buffer Size (samples):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="194"/>
        <source>WAV Manager (requires restart):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="211"/>
        <source>Append silence to each sound (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="222"/>
        <source>Genera&amp;l</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="223"/>
        <source>Soun&amp;d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="355"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/dialog_edit_preferences.py" line="355"/>
        <source>There are unsaved changes. Apply Changes?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>responseLight</name>
    <message>
        <location filename="../emid/__main__.py" line="448"/>
        <source>Light &amp; Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="424"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="460"/>
        <source>Light &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="482"/>
        <source>Light &amp; Text &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="430"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="467"/>
        <source>Text &amp; Smiley</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../emid/__main__.py" line="441"/>
        <source>Smiley</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
